## Indexes

Indexes are data structures that store information about documents. The most common type of index is a vector index, which stores a vector representation of each document. This is to store custom index retrievers that can be used `../chains/index`